@@ -69,12 +69,12 @@ def run_forecast_ensemble(
         named_model_list = model_list
     else:
         named_model_list = [
-            "greykite",
-            "prophet",
-            "naive",
-            "xgboost",
-            "randomforest",
-            "sarima"
+            "GreyKite",
+            "FBProphet",
+            "Naive",
+            "XGBoost",
+            "RandomForest",
+            "SARIMA"
         ]
 
     # For each model, run a full evaluation and add to the ensemble results
