@@ -286,9 +286,12 @@ class XGBoost(BaseModel):
         for ii in range(1, previous_periods):
             # Create recent lag periods
             result_df[f"{VALUE_COLUMN_NAME}_{ii}"] = time_series_df[VALUE_COLUMN_NAME].shift(ii)
-        result_df.dropna(inplace=True)
         period_indexes = pd.get_dummies(result_df.period_number)
-        dataframe = pd.concat([result_df, period_indexes], axis=1).drop(columns=["period_number"])
+        mask = True
+        for column in result_df.columns:
+            mask = mask & (~result_df[column].isnull())
+        dataframe = pd.merge(left=result_df, right=period_indexes, how="left", left_index=True, right_index=True)
+        dataframe = dataframe[mask]
 
         return dataframe
 
