@@ -49,15 +49,8 @@ def consolidate_scores(metrics: dict, average_actual: float):
     metrics["ae_composite"] = (metrics["accuracy_mae"] + metrics["accuracy_medae"]) / 2
     metrics["accuracy"] = (metrics["ae_composite"] + metrics["accuracy_mape"] + metrics["accuracy_rmse"]) / 3
 
-    r2 = metrics["r2"]
-    if r2 > 0.75:
-        confidence = "High"
-    elif r2 > 0.5:
-        confidence = "Medium"
-    else:
-        confidence = "Low"
-    metrics["confidence"] = confidence
+    metrics["fit"] = metrics["r2"]
 
-    return_metrics = ["accuracy_mape", "accuracy_rmse", "accuracy_mae", "accuracy_medae", "accuracy", "confidence"]
+    return_metrics = ["accuracy_mape", "accuracy_rmse", "accuracy_mae", "accuracy_medae", "accuracy", "fit"]
 
     return {metric: metrics[metric] for metric in return_metrics}
